import { DecodedCall } from 'components/ActionsBuilder/types';
import { useMemo } from 'react';
import { RichContractFunction } from './useRichContractRegistry';

const useRichContractData = (decodedCall: DecodedCall) => {
  const contractData = decodedCall.richData;

  // Find the rich contract data for the decoded call function.
  const functionData: RichContractFunction = useMemo(() => {
    if (!decodedCall || !decodedCall.richData) return null;
    const decodedFnName = decodedCall.function.name;
    const decodedFnTitle = decodedCall.functionTitle;
    const decodedFnParams = decodedCall.function.inputs
      .map(input => input.type)
      .join(',');

    return decodedCall.richData.functions.find(fn => {
      const nameMatch = fn.functionName === decodedFnName;
      const paramsMatch =
        fn.params.map(param => param.type).join(',') === decodedFnParams;
      const titleMatch = fn.title === decodedFnTitle;

      return nameMatch && paramsMatch && titleMatch;
    });
  }, [decodedCall]);

  return {
    contractData,
    functionData,
  };
};

export default useRichContractData;
